****************************************************
**APPENDIX C. BIAS IN TRADITIONAL DECISION-MAKING **
****************************************************

*TABLE C1.*

use "${data}/HHdata_QJPS_labeled.dta", clear

preserve

	eststo clear
	keep if VH_treat==0
	
	by D37, sort: eststo: estpost summarize female ageHH finprim cattlewealth bornvillage VHethnicmatch VHfam diffview
	esttab using "${tables}/table_c1_new.tex", replace cells("mean(fmt(a3))" sd(par fmt(a3))) ${stars1}
	eststo clear

restore

*TABLE C2.*

use "${data}/HHdata_QJPS_labeled.dta", clear

preserve
	keep if VH_treat==0
	
	local 	vars		///
			food_aid 	///
			mostfair 	///
			propcaseVH
			
	// Same View vs. Diff View
	eststo clear 
	tvsc `vars' if VH_treat == 0, by(sameview) 
	esttab using "${tables}/table_c2a_new.tex", replace ${stars1}		///
		cells("mu_1(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) mu_3(fmt(%9.3fc))" "se_2(par) se_1(par) se_3(par)") 	
	
	// Born Village
	eststo clear 
	tvsc `vars' if VH_treat == 0, by(bornvillage)
	esttab using "${tables}/table_c2b_new.tex", replace ${stars1}		///
		cells("mu_1(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) mu_3(fmt(%9.3fc))" "se_2(par) se_1(par) se_3(par)") 	
		
	// VH Fam
	eststo clear 
	tvsc `vars' if VH_treat == 0, by(VHfam)	
	esttab using "${tables}/table_c2c_new.tex", replace ${stars1}		///
		cells("mu_1(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) mu_3(fmt(%9.3fc))" "se_2(par) se_1(par) se_3(par)") 	
		
	// Female vs Male
	eststo clear 
	tvsc `vars' if VH_treat == 0, by(male) 
	esttab using "${tables}/table_c2d_new.tex", replace ${stars1}		///
		cells("mu_1(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) mu_3(fmt(%9.3fc))" "se_2(par) se_1(par) se_3(par)") 	
restore 

***********************************************
**APPENDIX E. SELECTED CIVIL SOCIETY LEADERS **
***********************************************

**********
*TABLE E1*
**********

**Table E1, column 1 from administrative data (No replication data available)
**Table E1, rows 1-6: Output from tabulations below, not automated
**Only rows 1-8 in columns 2-4 are automated

use "${data}/CLdata_QJPS_labeled.dta", clear
tab X1 if dare==0

eststo E1a: estpost sum female if dare==0
sum relative if dare==0
local pat_relative = r(mean)/2
estadd loc paternalrelative "`pat_relative'"

**Table E1, column 3:
tab X1 if dare==1

eststo E1b: estpost sum female if dare==1
sum relative if dare==1
local pat_relative = r(mean)/2
estadd loc paternalrelative "`pat_relative'"

**Table E1, column 4:

use "${data}/HHdata_QJPS_labeled.dta", clear

eststo E1c: estpost sum female if D37==2
sum VHfam if D37==2
local pat_relative = r(mean)/2
estadd loc paternalrelative "`pat_relative'"

esttab E1a E1b E1c using "${tables}/TableE1", tex replace cells("mean(fmt(a3))" sd(par fmt(a3))) stats(paternalrelative) label nodepvar noobs onecell

	 
**********************************
**APPENDIX F. BALANCE STATISTICS**
**********************************

**********
*TABLE F1*
**********

use "${data}/VHdata_QJPS_labeled.dta", clear

*** --------------------------------
*** Workshop vs No Workshop
*** --------------------------------

// Panel A. Village Characteristics 
local indexlist_vl communal numhouseholds numbergroups 

eststo clear
tvsc `indexlist_vl', by(VH_treat)
esttab using "${tables}/TableF1a_new.tex", replace ${stars1}		///
		cells("mu_2(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) d_p(fmt(%9.3fc))") 
		
// Panel B. VH Characteristics
local indexlist_vh womenVH moreprimary age tenure VH_bornvillage logcattlewealth ZANUPF_para

eststo clear
tvsc `indexlist_vh', by(VH_treat)
esttab using "${tables}/TableF1b_new.tex", replace ${stars1}		///
		cells("mu_2(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) d_p(fmt(%9.3fc))") 

// Panel C. HH survey respondent characteristics
use "${data}/HHdata_QJPS_labeled.dta", replace

local indexlist2 female finprim ageHH bornvillage wagelabor VHfam VHethnicmatch logcattlewealth diffview

eststo clear
tvsc_cc `indexlist2', by(VH_treat) clus_id(cc)
esttab using "${tables}/TableF1c_new.tex", replace ${stars1}		///
		cells("mu_2(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) d_p(fmt(%9.3fc))") 

*** --------------------------------
*** VC Only vs VC - & CL comparison 
*** --------------------------------

use "${data}/VHdata_QJPS_labeled.dta", clear

// Generate dummy that takes 1 if VH treat = 1 & CL = 1, and zero if CL = 0
gen 	VH_treat_cl = 1 if VH_treat==1 & cl==1
replace VH_treat_cl = 0 if VH_treat==1 & cl==0

// Panel A. Village Characteristics 
local indexlist_vl communal numhouseholds numbergroups 

eststo clear
tvsc `indexlist_vl', by(VH_treat_cl)
esttab using "${tables}/TableF1a_new2.tex", replace ${stars1}			///
		cells("mu_2(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) d_p(fmt(%9.3fc))") 

// Panel B. VH Characteristics
local indexlist_vh womenVH moreprimary age tenure VH_bornvillage logcattlewealth ZANUPF_para

eststo clear
tvsc `indexlist_vh', by(VH_treat_cl) 
esttab using "${tables}/TableF1b_new2.tex", replace ${stars1}			///
		cells("mu_2(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) d_p(fmt(%9.3fc))") 	

// Panel C. HH survey respondent characteristics
use "${data}/HHdata_QJPS_labeled.dta", clear

// Generate dummy that takes 1 if VH treat = 1 & CL = 1, and zero if CL = 0
gen 	VH_treat_cl = 1 if VH_treat==1 & cl==1
replace VH_treat_cl = 0 if VH_treat==1 & cl==0

local indexlist2 female finprim ageHH bornvillage wagelabor VHfam VHethnicmatch logcattlewealth diffview

eststo clear
tvsc_cc `indexlist2', by(VH_treat_cl) clus_id(cc)
esttab using "${tables}/TableF1c_new2.tex", replace ${stars1}		///
		cells("mu_2(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) d_p(fmt(%9.3fc))") 

		
******************************************
*APPENDIX H: MAIN RESULTS IN TABULAR FORM*
******************************************

**********
*TABLE H1*
**********

use "${data}/VHdata_QJPS_labeled.dta", clear

eststo clear

evccl st_proceduresindex, by(VH_treat)
esttab using "${tables}/TableH1_new.tex", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	
	
************
**TABLE H2**
************

use "${data}/HHdata_QJPS_labeled.dta", clear

eststo clear
eststo e1: evccl_diff biasindex if diffview == 1, by(VH_treat) clus_id(cc) 
esttab e1 using "${tables}/TableH2a_new.tex",  replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	

esttab ,  ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	

eststo e2: evccl resolvedindex st_legitimacyindex, by(VH_treat) clus_id(cc)
esttab e2 using "${tables}/TableH2b_new.tex",  replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	

************
**TABLE H3**
************

use "${data}/HHdata_QJPS_labeled.dta", clear

eststo clear
eststo e1: evccl_diff biasindex food_aid mostfair if diffview == 1, by(VH_treat) clus_id(cc) 
esttab e1 using "${tables}/TableH3a_new.tex",  replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	

eststo e2: evccl resolvedindex nofoodaidneed noconflicts, by(VH_treat) clus_id(cc)
esttab e2 using "${tables}/TableH3b_new.tex",  replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	

************
**TABLE H4**
************

use "${data}/VHdata_QJPS_labeled.dta", clear

eststo clear
evccl_diff testknowledge testattitudes st_proceduresindex if closehat_di == 0, by(VH_treat)
esttab using "${tables}/TableH4a_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	

	
use "${data}/HHdata_QJPS_labeled.dta", clear

eststo clear
evccl_diff biasindex if closehat_di == 0 & diffview == 1, by(VH_treat) clus_id(cc)
esttab using "${tables}/TableH4b_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	
	
eststo clear
evccl_diff st_legitimacyindex if closehat_di == 0, by(VH_treat)	clus_id(cc) 
esttab using "${tables}/TableH4c_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 		


use "${data}/VHdata_QJPS_labeled.dta", clear		 
		 
eststo clear
evccl_diff testknowledge testattitudes st_proceduresindex if closehat_di == 1, by(VH_treat)
esttab using "${tables}/TableH4a2_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	

use "${data}/HHdata_QJPS_labeled.dta", clear


eststo clear
evccl_diff biasindex if closehat_di == 1 & diffview == 1, by(VH_treat) clus_id(cc)
esttab using "${tables}/TableH4b2_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 
	
eststo clear
evccl_diff st_legitimacyindex if closehat_di == 1, by(VH_treat) clus_id(cc)
esttab using "${tables}/TableH4c2_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 

**************************************************
*APPENDIX I: ROBUSTNESS OF MEASUREMENT STRATEGIES*	
**************************************************
	
***************
**TABLE I.1*
***************

use "${data}/VHdata_QJPS_labeled.dta", clear

eststo clear
evccl st_proceduresindex percwomendare consult_women consult_RMC transparency nofee, by(VH_treat) 
esttab using "${tables}/TableI1_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 

***************
*TABLE I.2*
***************

use "${data}/CLdata_QJPS_labeled.dta", clear


eststo clear
evccl st_procedures_indexCL, by(VH_treat) 
esttab using "${tables}/TableI2a_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 

use "${data}/VHdata_QJPS_labeled.dta", clear

eststo clear
evccl st_diversity_index, by(VH_treat) 
esttab using "${tables}/TableI2b_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 
	

**************
*TABLE I.3*
**************

use "${data}/HHdata_QJPS_labeled.dta", clear

eststo clear
evccl st_legitimacyindex trust relationship compliance livestocktoVH, by(VH_treat) clus_id(cc)
esttab using "${tables}/TableI3_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 


*****************
**APPENDIX I.4 **
*****************

use "${data}/HHdata_QJPS_labeled.dta", replace

// 1st column
eststo clear
eststo reg1: reg diffview VH_treat cl, cluster(cc)
estadd scalar p_diff = e(F)

// 2nd column
local balance female finprim bornvillage wagelabor VHfam VHethnicmatch ageHH logcattlewealth

foreach var in `balance'{
	gen `var'XVH = `var'*VH_treat
	gen `var'XCL = `var'*cl
	loc vlist `vlist' `var'XVH `var'XCL
}

eststo reg2: reg diffview VH_treat cl `vlist' `balance', cluster(cc)

test VH_treat cl `vlist'
estadd scalar p_diff = r(p)

// Fix labels for the table
local balance female finprim bornvillage wagelabor VHfam VHethnicmatch ageHH logcattlewealth
foreach var in `balance' {
	local label : variable label `var'
	display "`label'"
	label variable `var'XVH "`label' $\times$ VC"
	label variable `var'XCL "`label' $\times$ CL"
}

label var VH_treat	"Effect of Workshop on VC"
label var cl 		"Effect of CL"

esttab reg1 reg2 using "${tables}/tableI4_new.tex", replace keep(VH_treat cl `vlist') ${stars3} scalars("p_diff P-value from F-test")

*************
**APPENDIX J*
*************

**********
*TABLE J1*
**********

use "${data}/VHdata_QJPS_labeled.dta", clear

// Fix labels
label var parentsherewhenborn "VC Born in Village"
label var close " "

// Regression
eststo clear 
eststo reg1: logit close vehicles notfarminginc moreprimary parentsherewhenborn if cl==1
estat classification, cutoff(0.35)
estadd scalar corr = r(P_corr)

// Export
esttab using "${tables}/tableJ1_new.tex", replace ${stars3} scalars("corr PCC (0.35 cutoff)")


******************************
*APPENDIX K: MECHANISMS TABLE*
******************************

**********
*TABLE K1*
**********

use "${data}/VHdata_QJPS_labeled.dta", clear


eststo clear
evccl indepgovt2, by(VH_treat)
esttab using "${tables}/TableK1a_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	

use "${data}/HHdata_QJPS_labeled.dta", replace

eststo clear
evccl testknowledgeHH raisedissue, by(VH_treat) clus_id(cc)
esttab using "${tables}/TableK1b_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	

use "${data}/CLdata_QJPS_labeled.dta", clear

eststo clear
evccl_diff testknowledgeCL logexchangeinfo if dare==0, by(VH_treat)
esttab using "${tables}/TableK1c_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	


**********
*TABLE K2*
**********

use "${data}/VHdata_QJPS_labeled.dta", clear

eststo clear
evccl_diff testknowledge st_proceduresindex if moreprimary == 0, by(VH_treat)
esttab using "${tables}/TableK2a_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	

use "${data}/HHdata_QJPS_labeled.dta", clear

eststo clear
evccl_diff biasindex if moreprimary == 0 & diffview == 1, by(VH_treat) clus_id(cc)
esttab using "${tables}/TableK2b_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	
	
eststo clear
evccl_diff st_legitimacyindex if moreprimary == 0, by(VH_treat)	clus_id(cc) 
esttab using "${tables}/TableK2c_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 		


use "${data}/VHdata_QJPS_labeled.dta", clear

eststo clear
evccl_diff testknowledge st_proceduresindex if moreprimary == 1, by(VH_treat)
esttab using "${tables}/TableK2d_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	

use "${data}/HHdata_QJPS_labeled.dta", clear

eststo clear
evccl_diff biasindex if moreprimary == 1 & diffview == 1, by(VH_treat) clus_id(cc)
esttab using "${tables}/TableK2e_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	
	
eststo clear
evccl_diff st_legitimacyindex if moreprimary == 1, by(VH_treat)	clus_id(cc) 
esttab using "${tables}/TableK2f_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 		

	
	
**********
*TABLE K3*
**********

use "${data}/VHdata_QJPS_labeled.dta", clear

eststo clear
evccl_diff testknowledge st_proceduresindex if ccount == 1, by(VH_treat)
esttab using "${tables}/TableK3a_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	

use "${data}/HHdata_QJPS_labeled.dta", clear

eststo clear
evccl_diff biasindex if ccount == 1 & diffview == 1, by(VH_treat) clus_id(cc)
esttab using "${tables}/TableK3b_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	
	
eststo clear
evccl_diff st_legitimacyindex if ccount == 1, by(VH_treat)	clus_id(cc) 
esttab using "${tables}/TableK3c_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 		

use "${data}/VHdata_QJPS_labeled.dta", clear

eststo clear
evccl_diff testknowledge st_proceduresindex if ccount == 0, by(VH_treat)
esttab using "${tables}/TableK3d_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	

use "${data}/HHdata_QJPS_labeled.dta", clear

eststo clear
evccl_diff biasindex if ccount == 0 & diffview == 1, by(VH_treat) clus_id(cc)
esttab using "${tables}/TableK3e_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	
	
eststo clear
evccl_diff st_legitimacyindex if ccount == 0, by(VH_treat)	clus_id(cc) 
esttab using "${tables}/TableK3f_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 		

	
**********
*TABLE K4*
**********

use "${data}/HHdata_QJPS_labeled.dta", clear


eststo clear
evccl_diff biasindex st_legitimacyindex if diffview == 1, by(VH_treat) clus_id(cc)
esttab using "${tables}/TableK4a_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	
	
eststo clear
evccl_diff biasindex st_legitimacyindex if diffview == 0, by(VH_treat)	clus_id(cc) 
esttab using "${tables}/TableK4b_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 		


***********************************************
*APPENDIX L: COMPARISON WITH PRE-ANALYSIS PLAN*
***********************************************

***********
*TABLE L.2*
***********

use "${data}/VHdata_QJPS_labeled.dta", clear

	// Add letters to labels so can compare to Table L1
label var st_knowledge_index "A. Knowledge Index"
label var st_attitude_index "B. Attitudes Index"
label var st_legitimacyVH_index "N. Legitimacy of VC"

eststo clear

eststo clear
evccl_nob st_knowledge_index st_attitude_index st_legitimacyVH_index, by(VH_treat) 
esttab using "${tables}/TableL2_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	
	


**********
*TABLE L3*
**********

*Village Head's Impartiality*
*% of respondents who know of people being excluded from food aid lists (as calculated from list experiment)

use "${data}/HHdata_QJPS_labeled.dta", clear

preserve

	keep F2_est VH_treat cl cc

	collapse F2_est VH_treat cl, by(cc)

	reg F2_est if VH_treat==0
	reg F2_est VH_treat cl
	lincom _b[VH_treat] + _b[cl]

	// Fix labels
label var F2_est "D. Prop. HHs report food aid bias"
	
eststo clear
evccl_nob F2_est, by(VH_treat)  
esttab using "${tables}/TableL3a_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	

restore

use "${data}/HHdata_QJPS_labeled.dta", clear


    //Fix labels
label var mostfair "E. Perceive most court decisions fair"
label var st_legitimacyindex "M. Legitimacy of VC"

//fix labels work-around: create duplicate variables with different labels for sub-groups*
gen food_aid2 = food_aid
gen assistance2 = assistance

gen food_aid3 = food_aid
gen assistance3 = assistance

label var food_aid2 "F. Received food aid (diff view)"
label var food_aid3 "H. Received food aid (diff family)"
label var assistance2 "G. Received any assistance (diff view)"
label var assistance3 "I. Received any assistance (diff family)"


eststo clear
evccl_nob mostfair, by(VH_treat) clus_id(cc)
esttab using "${tables}/TableL3b_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	
	

eststo clear
evccl_diff_nob food_aid2 assistance2 if diffview == 1, by(VH_treat) clus_id(cc)
esttab using "${tables}/TableL3c_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	
	

eststo clear
evccl_diff_nob food_aid3 assistance3 if VHfam == 0, by(VH_treat) clus_id(cc)
esttab using "${tables}/TableL3d_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	
	
eststo clear
evccl_nob st_legitimacyindex, by(VH_treat) clus_id(cc)
esttab using "${tables}/TableL3e_new", replace ${stars1}		///
	cells("mu_0(fmt(%9.3fc)) mu_1(fmt(%9.3fc)) mu_3(fmt(%9.3fc)) mu_2(fmt(%9.3fc)) N_S(fmt(%9.0fc))" "se_0(par) se_1(par) se_3(par) se_2(par)") 	
	
	 
**********
*TABLE L4*
**********

*Effect of wealth on likelihood of receiving food aid, maize seed or grain loans

gen VHXwealth = VH_treat*logcattlewealth
gen CLXwealth = cl*logcattlewealth

// Fix labels
label var assistance "J. Received Assistance"
label var logcattlewealth "Livestock Wealth (Logged)"
label var VHXwealth "Livestock Wealth (Logged) X VC"
label var CLXwealth "Livestock Wealth (Logged) X CL"

eststo clear

reg assistance VH_treat cl logcattlewealth VHXwealth CLXwealth, cluster(cc)
rounding logcattlewealth, estadd(bse0)
estadd loc ob1 = e(N)
rounding VHXwealth, estadd(bse1)
rounding CLXwealth, estadd(bse2)
lincom _b[VHXwealth] + _b[CLXwealth]
roundlincom, estadd(bse3)

eststo TableL4

esttab using "${tables}/TableL4", tex replace keep(VH_treat) nostar nogaps drop(VH_treat) ///
		b("%9.3f") se("%9.3f") onecell label nonotes stats(bse0 bse1 bse3 bse2 ob1, labels("Livestock Wealth (Log)" "Livestock Wealth (Log) X VC" "Livestock Wealth (Log) X VC \& CL" "Livestock Wealth (Log) X CL" "N"))	


		
